@@ -2,6 +2,7 @@ from apache_beam.utils.timestamp import MIN_TIMESTAMP
 from apache_beam.utils.windowed_value import WindowedValue
 from apache_beam.transforms.window import GlobalWindow
 from apache_beam.transforms import PTransform, ParDo, DoFn
+from feature_creation_tools.feature_creation_utils import LabelEncoderExt
 import google.cloud.storage as storage
 import pandas as pd
 import pickle
@@ -64,7 +65,7 @@ class BatchingFn(PTransform):
 class _CreateCategoricalEncodedVariables(DoFn):
 
     def process(self, data):
-        from user_feature_utils.feature_creation_utils import LabelEncoderExt
+
         # Multi Label Binarizer Variables
         # Split out Equipment Types
 
@@ -449,11 +450,13 @@ class _CreateCategoricalEncodedVariables(DoFn):
 
         return [df, ]
 
+
 class CreateCategoricalEncodedVariables(PTransform):
 
     def expand(self, pcoll):
         return pcoll | ParDo(_CreateCategoricalEncodedVariables())
 
+
 class _SaveDataframeToGCS(DoFn):
 
     def process(self, df):
